import type { Settings as LayoutSettings } from '@ant-design/pro-components';
import type { RequestConfig, RunTimeLayoutConfig } from '@umijs/max';
import { history } from '@umijs/max';
import defaultSettings from '../config/defaultSettings';
import { accountCurrentService } from './services';
import { initialColor, initialStyle } from './utils/preference';
import { authorization } from './utils/token';

const loginPath = '/passport/login';

/**
 * @name getInitialState
 * @see  https://umijs.org/zh-CN/plugins/plugin-initial-state
 * */
export async function getInitialState(): Promise<{
  settings?: Partial<LayoutSettings>;
  account?: Account;
  loading?: boolean;
  fetchCurrent?: () => Promise<Account | undefined>;
}> {
  // 初始化主题颜色
  initialColor();
  // 初始化主题风格
  initialStyle();
  // 获取当前账号
  const fetchCurrent = async () => {
    try {
      const result = await accountCurrentService();
      return result?.data;
    } catch (error) {
      history.push(loginPath);
    }
    return undefined;
  };
  // 如果不是登录页面，执行
  if (window.location.pathname !== loginPath) {
    const account = await fetchCurrent();
    return {
      fetchCurrent,
      account,
      settings: defaultSettings,
    };
  }
  return {
    fetchCurrent,
    settings: defaultSettings,
  };
}

/**
 * @name layout 布局
 * @descrption ProLayout
 * @see https://procomponents.ant.design/components/layout
 */
export const layout: RunTimeLayoutConfig = ({ initialState }) => {
  return {
    pure: true,
    onPageChange: () => {
      // 如果没有登录，重定向到 login
      if (!initialState?.account && window.location.pathname !== loginPath) {
        history.push(loginPath);
      }
    },
    ...initialState?.settings,
  };
};

/**
 * @name request 配置，可以配置错误处理
 * @descrption 它基于 axios 和 ahooks 的 useRequest 提供了一套统一的网络请求和错误处理方案。
 * @see https://umijs.org/docs/max/request#配置
 */
export const request: RequestConfig = {
  requestInterceptors: [
    (config: any) => {
      // 拦截请求配置，进行个性化处理。
      return { ...config, headers: { ...config.headers, ...authorization() } };
    },
  ],
  // paramsSerializer: (params: any) => {
  //   // 参数序列化
  //   return paramsSerialize(params);
  // },
};
