import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Link } from '@umijs/max';
import { Button, message, Modal } from 'antd';
import { useRef, useState } from 'react';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import {
  customerEditService,
  customerPageService,
  customerRemoveService,
  customerUrgeService,
} from './service';

const Page = () => {
  const { account } = useAccount();
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const paymentModeEnum = useDictEnum('payment.mode');
  const rulePlanEnum = useDictEnum('rule.plan');
  const systemStatusEnum = useDictEnum('system.status');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '客户名称',
      dataIndex: 'name',
      hideInSearch: true,
      render: (text: any, record: any) => <Link to={`./${record.id}`}>{text}</Link>,
      width: 200,
    },
    {
      title: '联系人',
      dataIndex: 'contact',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '联系手机',
      dataIndex: 'phone',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '付费方式',
      dataIndex: 'mode',
      valueType: 'select',
      valueEnum: paymentModeEnum,
      filters: true,
      onFilter: true,
      width: 200,
    },
    {
      title: '第一预设值',
      valueType: 'digit',
      dataIndex: 'first',
      hideInSearch: true,
      sorter: true,
      width: 200,
    },
    {
      title: '第二预设值',
      valueType: 'digit',
      dataIndex: 'second',
      hideInSearch: true,
      sorter: true,
      width: 200,
    },
    {
      title: '账户余额',
      valueType: 'digit',
      dataIndex: 'amount',
      hideInSearch: true,
      sorter: true,
      width: 200,
    },
    {
      title: '计费规则',
      dataIndex: 'plan',
      valueType: 'select',
      valueEnum: rulePlanEnum,
      filters: true,
      onFilter: true,
      width: 200,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: systemStatusEnum,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 300,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 300,
      render: (_text: any, record: any) => [
        <a
          key="notice"
          onClick={() => {
            Modal.confirm({
              title: '确定催费通知吗？',
              onOk: async () => {
                await customerUrgeService(record);
                message.info('催费通知已发送');
              },
            });
          }}
        >
          催费
        </a>,
        <a
          key="status"
          onClick={() => {
            Modal.confirm({
              title: '确定修改状态吗？',
              onOk: async () => {
                const params = {
                  ...record,
                  status: record?.status === 'disable' ? 'enable' : 'disable',
                };
                await customerEditService(params);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          {record?.status === 'disable' ? '启用' : '禁用'}
        </a>,
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await customerRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="客户列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 添加
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await customerPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
