import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons';
import {
  Alert,
  Button,
  Card,
  DatePicker,
  Divider,
  Form,
  InputNumber,
  message,
  Select,
  Space,
} from 'antd';
import moment from 'moment';
import { ruleAddService, ruleEditService } from './service';

const Rule = ({ type, flag, current, onRefresh }: any) => {
  const [form] = Form.useForm();

  const initialValues = {
    ...current,
    gradient: {
      ...current?.gradient,
      start: current?.gradient?.start && moment(current?.gradient?.start, 'YYYY-MM-DD HH:mm:ss'),
    },
  };

  const onFinish = async () => {
    const values = await form.validateFields();
    const params = {
      ...values,
      gradient: {
        ...values?.gradient,
        start: values?.gradient?.start?.format('YYYY-MM-DD HH:mm:ss'),
      },
    };
    const result = flag
      ? await ruleAddService({ ...current, ...params })
      : await ruleEditService({ ...current, ...params });
    if (result?.success) {
      onRefresh();
      message.success('保存规则成功');
    } else {
      message.error('保存规则失败');
    }
  };

  return (
    <Card bordered={false}>
      {flag && <Alert message="规则未保存，请即时保存，否则计费将出错！" type="warning" showIcon />}
      <div style={{ margin: 'auto', marginTop: 16, maxWidth: 800 }}>
        <Form
          labelCol={{ span: 4 }}
          wrapperCol={{ span: 20 }}
          form={form}
          initialValues={initialValues}
          onFinish={onFinish}
        >
          {type === 'operator' && (
            <>
              <Divider>电价计费规则设置</Divider>
              <Form.Item
                label="正常电价"
                name="cost"
                rules={[{ required: true, message: '正常电价必填' }]}
              >
                <InputNumber placeholder="请输入" style={{ width: '100%' }} />
              </Form.Item>
              <Form.Item label="分时电价">
                <Form.List name="fluctuates">
                  {(fields, { add, remove }) => (
                    <>
                      {fields.map(({ key, name, ...restField }) => (
                        <Space key={key} align="baseline" style={{ width: '100%' }}>
                          <Form.Item
                            {...restField}
                            // label="分时电价"
                            name={[name, 'cost']}
                            rules={[{ required: true, message: '分时电价必填' }]}
                          >
                            <InputNumber placeholder="分时电价" style={{ width: 150 }} />
                          </Form.Item>
                          <Form.Item
                            {...restField}
                            // label="开始时刻"
                            name={[name, 'start']}
                            rules={[{ required: true, message: '开始时刻必填' }]}
                          >
                            <InputNumber
                              min={0}
                              max={23}
                              precision={0}
                              placeholder="开始时刻(0-23)"
                              style={{ width: 150 }}
                            />
                          </Form.Item>
                          <Form.Item
                            {...restField}
                            // label="结束时刻"
                            name={[name, 'end']}
                            rules={[{ required: true, message: '结束时刻必填' }]}
                          >
                            <InputNumber
                              min={1}
                              max={24}
                              precision={0}
                              placeholder="结束时刻(1-24)"
                              style={{ width: 150 }}
                            />
                          </Form.Item>
                          <Form.Item
                            {...restField}
                            // label="分时标签"
                            name={[name, 'label']}
                            rules={[{ required: true, message: '分时标签必选' }]}
                          >
                            <Select
                              placeholder="分时标签"
                              options={[
                                { value: 'valley', label: '谷' },
                                { value: 'flat', label: '平' },
                                { value: 'peak', label: '峰' },
                              ]}
                              allowClear
                              style={{ width: 150 }}
                            />
                          </Form.Item>
                          <MinusCircleOutlined onClick={() => remove(name)} />
                        </Space>
                      ))}
                      <Form.Item>
                        <Button type="dashed" onClick={() => add()} block icon={<PlusOutlined />}>
                          增加分时电价
                        </Button>
                      </Form.Item>
                    </>
                  )}
                </Form.List>
              </Form.Item>
            </>
          )}
          <Divider>服务计费规则设置</Divider>
          <Form.Item
            label="正常服务费"
            name="service"
            rules={[{ required: true, message: '正常服务费必填' }]}
          >
            <InputNumber placeholder="请输入" style={{ width: '100%' }} />
          </Form.Item>
          <Form.Item
            label="梯度服务费"
            name={['gradient', 'service']}
            rules={[{ required: true, message: '梯度服务费必填' }]}
          >
            <InputNumber placeholder="请输入" style={{ width: '100%' }} />
          </Form.Item>
          <Form.Item
            label="计费周期"
            name={['gradient', 'cycle']}
            rules={[{ required: true, message: '计费周期必选' }]}
          >
            <Select
              placeholder="请选择"
              options={[
                { value: 12, label: '年' },
                { value: 3, label: '季' },
                { value: 1, label: '月' },
              ]}
              allowClear
            />
          </Form.Item>
          <Form.Item
            label="计费日期"
            name={['gradient', 'start']}
            rules={[{ required: true, message: '计费日期必选' }]}
          >
            <DatePicker placeholder="请选择" allowClear style={{ width: '100%' }} />
          </Form.Item>
          <Form.Item
            label="电量阈值"
            name={['gradient', 'threshold']}
            rules={[{ required: true, message: '电量阈值必填' }]}
          >
            <InputNumber placeholder="请输入" style={{ width: '100%' }} />
          </Form.Item>
          <Divider>电损计费规则设置</Divider>
          <Form.Item
            label="电损费用"
            name="addition"
            rules={[{ required: true, message: '电损费用必填' }]}
          >
            <InputNumber placeholder="请输入" style={{ width: '100%' }} />
          </Form.Item>
          <Form.Item wrapperCol={{ offset: 4, span: 20 }}>
            <Space>
              <Button type="primary" htmlType="submit">
                保存
              </Button>
              <Button htmlType="reset">重置</Button>
            </Space>
          </Form.Item>
        </Form>
      </div>
    </Card>
  );
};

export default Rule;
